==> jc-1.4.0.tar.gz: javax/swing/SizeRequirements.h <==
// public class javax.swing.SizeRequirements

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d347f40329c1b3f7 javax_swing_SizeRequirements

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_SizeRequirements_H_
#define _JC_javax_swing_SizeRequirements_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_SizeRequirements$object;

// Typedefs
typedef struct _jc_javax_swing_SizeRequirements$sub_refs	_jc_javax_swing_SizeRequirements$sub_refs;
typedef struct _jc_javax_swing_SizeRequirements$sub_nonrefs	_jc_javax_swing_SizeRequirements$sub_nonrefs;
typedef struct _jc_javax_swing_SizeRequirements$refs	_jc_javax_swing_SizeRequirements$refs;
typedef struct _jc_javax_swing_SizeRequirements$nonrefs	_jc_javax_swing_SizeRequirements$nonrefs;
typedef struct _jc_javax_swing_SizeRequirements$object	_jc_javax_swing_SizeRequirements$object;

typedef struct _jc_javax_swing_SizeRequirements$fields_struct	_jc_javax_swing_SizeRequirements$fields_struct;
typedef const struct _jc_javax_swing_SizeRequirements$vmethods	_jc_javax_swing_SizeRequirements$vmethods;
typedef const struct _jc_javax_swing_SizeRequirements$vtable	_jc_javax_swing_SizeRequirements$vtable;
typedef const struct _jc_javax_swing_SizeRequirements$vtype	_jc_javax_swing_SizeRequirements$vtype;

// Class fields structure
struct _jc_javax_swing_SizeRequirements$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_SizeRequirements$fields_struct _jc_javax_swing_SizeRequirements$class_fields;

// Constructors
extern void _jc_javax_swing_SizeRequirements$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_SizeRequirements$object *);
extern void _jc_javax_swing_SizeRequirements$method$_init$524f578f1d88413b(_jc_env *, struct _jc_javax_swing_SizeRequirements$object *, jint, jint, jint, jfloat);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_swing_SizeRequirements$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_swing_SizeRequirements$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_SizeRequirements$method_info$toString$7ea43b33b80a3070;

// Static methods
extern _jc_int_array *_jc_javax_swing_SizeRequirements$method$adjustSizes$11db5e3fb012e29e(_jc_env *, jint, struct _jc_object_array *);
extern void _jc_javax_swing_SizeRequirements$method$calculateAlignedPositions$865e5c038671407b(_jc_env *, jint, struct _jc_javax_swing_SizeRequirements$object *, struct _jc_object_array *, struct _jc_int_array *, struct _jc_int_array *);
extern void _jc_javax_swing_SizeRequirements$method$calculateTiledPositions$bcd09f3c6d2a1020(_jc_env *, jint, struct _jc_javax_swing_SizeRequirements$object *, struct _jc_object_array *, struct _jc_int_array *, struct _jc_int_array *);
extern struct _jc_javax_swing_SizeRequirements$object *_jc_javax_swing_SizeRequirements$method$getAlignedSizeRequirements$636f9ff403ae6ca9(_jc_env *, struct _jc_object_array *);
extern struct _jc_javax_swing_SizeRequirements$object *_jc_javax_swing_SizeRequirements$method$getTiledSizeRequirements$71597bfa59dafb80(_jc_env *, struct _jc_object_array *);

// Virtual methods structure
struct _jc_javax_swing_SizeRequirements$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_swing_SizeRequirements$object *);
};

// Vtable
struct _jc_javax_swing_SizeRequirements$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_SizeRequirements$vmethods	javax_swing_SizeRequirements;
};

// Vtype
struct _jc_javax_swing_SizeRequirements$vtype {
	_jc_type			type;
	_jc_javax_swing_SizeRequirements$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_SizeRequirements$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_SizeRequirements$refs {
    _jc_javax_swing_SizeRequirements$sub_refs	javax_swing_SizeRequirements;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_SizeRequirements$sub_nonrefs {
	jint	minimum;
	jint	preferred;
	jint	maximum;
	jfloat	alignment;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_SizeRequirements$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_SizeRequirements$sub_nonrefs	javax_swing_SizeRequirements;
};

// Object instance structure
struct _jc_javax_swing_SizeRequirements$object {
	_jc_javax_swing_SizeRequirements$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_SizeRequirements$vtype	*vtype;
	_jc_javax_swing_SizeRequirements$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_SizeRequirements$vtype _jc_javax_swing_SizeRequirements$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_SizeRequirements, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_SizeRequirements$class_object;

#endif	/* _JC_javax_swing_SizeRequirements_H_ */

==> jc-1.4.5.tar.gz: javax/swing/SizeRequirements.h <==
// public class javax.swing.SizeRequirements

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d347f40329c1b3f7 javax_swing_SizeRequirements

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_SizeRequirements_H_
#define _JC_javax_swing_SizeRequirements_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_SizeRequirements$object;

// Typedefs
typedef struct _jc_javax_swing_SizeRequirements$sub_refs	_jc_javax_swing_SizeRequirements$sub_refs;
typedef struct _jc_javax_swing_SizeRequirements$sub_nonrefs	_jc_javax_swing_SizeRequirements$sub_nonrefs;
typedef struct _jc_javax_swing_SizeRequirements$refs	_jc_javax_swing_SizeRequirements$refs;
typedef struct _jc_javax_swing_SizeRequirements$nonrefs	_jc_javax_swing_SizeRequirements$nonrefs;
typedef struct _jc_javax_swing_SizeRequirements$object	_jc_javax_swing_SizeRequirements$object;

typedef struct _jc_javax_swing_SizeRequirements$fields_struct	_jc_javax_swing_SizeRequirements$fields_struct;
typedef const struct _jc_javax_swing_SizeRequirements$vmethods	_jc_javax_swing_SizeRequirements$vmethods;
typedef const struct _jc_javax_swing_SizeRequirements$vtable	_jc_javax_swing_SizeRequirements$vtable;
typedef const struct _jc_javax_swing_SizeRequirements$vtype	_jc_javax_swing_SizeRequirements$vtype;

// Class fields structure
struct _jc_javax_swing_SizeRequirements$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_SizeRequirements$fields_struct _jc_javax_swing_SizeRequirements$class_fields;

// Constructors
extern void _jc_javax_swing_SizeRequirements$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_SizeRequirements$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_SizeRequirements$method$_init$524f578f1d88413b(_jc_env *, struct _jc_javax_swing_SizeRequirements$object *, jint, jint, jint, jfloat) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_swing_SizeRequirements$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_swing_SizeRequirements$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_SizeRequirements$method_info$toString$7ea43b33b80a3070;

// Static methods
extern _jc_int_array *_jc_javax_swing_SizeRequirements$method$adjustSizes$11db5e3fb012e29e(_jc_env *, jint, struct _jc_object_array *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_SizeRequirements$method$calculateAlignedPositions$865e5c038671407b(_jc_env *, jint, struct _jc_javax_swing_SizeRequirements$object *, struct _jc_object_array *, struct _jc_int_array *, struct _jc_int_array *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_SizeRequirements$method$calculateTiledPositions$bcd09f3c6d2a1020(_jc_env *, jint, struct _jc_javax_swing_SizeRequirements$object *, struct _jc_object_array *, struct _jc_int_array *, struct _jc_int_array *) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_SizeRequirements$object *_jc_javax_swing_SizeRequirements$method$getAlignedSizeRequirements$636f9ff403ae6ca9(_jc_env *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_SizeRequirements$object *_jc_javax_swing_SizeRequirements$method$getTiledSizeRequirements$71597bfa59dafb80(_jc_env *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_SizeRequirements$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_swing_SizeRequirements$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_SizeRequirements$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_SizeRequirements$vmethods	javax_swing_SizeRequirements;
};

// Vtype
struct _jc_javax_swing_SizeRequirements$vtype {
	_jc_type			type;
	_jc_javax_swing_SizeRequirements$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_SizeRequirements$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_SizeRequirements$refs {
    _jc_javax_swing_SizeRequirements$sub_refs	javax_swing_SizeRequirements;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_SizeRequirements$sub_nonrefs {
	jint	minimum;
	jint	preferred;
	jint	maximum;
	jfloat	alignment;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_SizeRequirements$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_SizeRequirements$sub_nonrefs	javax_swing_SizeRequirements;
};

// Object instance structure
struct _jc_javax_swing_SizeRequirements$object {
	_jc_javax_swing_SizeRequirements$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_SizeRequirements$vtype	*vtype;
	_jc_javax_swing_SizeRequirements$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_SizeRequirements$vtype _jc_javax_swing_SizeRequirements$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_SizeRequirements, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_SizeRequirements$class_object;

#endif	/* _JC_javax_swing_SizeRequirements_H_ */
